@@ -1,6 +1,6 @@
 //! `dump` subcommand
 
-use crate::{commands::open_repository_indexed, status_err, Application, RUSTIC_APP};
+use crate::{repository::CliIndexedRepo, status_err, Application, RUSTIC_APP};
 
 use abscissa_core::{Command, Runnable, Shutdown};
 use anyhow::Result;
@@ -15,7 +15,11 @@ pub(crate) struct DumpCmd {
 
 impl Runnable for DumpCmd {
     fn run(&self) {
-        if let Err(err) = self.inner_run() {
+        if let Err(err) = RUSTIC_APP
+            .config()
+            .repository
+            .run_indexed(|repo| self.inner_run(repo))
+        {
             status_err!("{}", err);
             RUSTIC_APP.shutdown(Shutdown::Crash);
         };
@@ -23,9 +27,8 @@ impl Runnable for DumpCmd {
 }
 
 impl DumpCmd {
-    fn inner_run(&self) -> Result<()> {
+    fn inner_run(&self, repo: CliIndexedRepo) -> Result<()> {
         let config = RUSTIC_APP.config();
-        let repo = open_repository_indexed(&config.repository)?;
 
         let node =
             repo.node_from_snapshot_path(&self.snap, |sn| config.snapshot_filter.matches(sn))?;
